/*
 * Created on 08.12.2004
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.laliluna.tutorials.finderexample.session.ejb;


import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import de.laliluna.tutorials.finderexample.entity.interfaces.BookLocal;
import de.laliluna.tutorials.finderexample.entity.interfaces.BookLocalHome;
import de.laliluna.tutorials.finderexample.entity.interfaces.CustomerLocal;
import de.laliluna.tutorials.finderexample.entity.interfaces.CustomerLocalHome;
import de.laliluna.tutorials.finderexample.entity.interfaces.CustomerValue;

/**
 * @author laliluna.de
 * 
 * @ejb.bean name = "FinderSession"
 *           type = "Stateless"
 *           display-name = "FinderSession"
 *           description = "FinderSession EJB"
 *           view-type = "remote"
 *           jndi-name = "ejb/FinderSessionHome"
 */
public class FinderSession implements SessionBean {
	
	/**
	 * Get all Customers from the local home interface
	 * Auslesen aller Kunden aus dem Local Home Interface
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public Collection getAllCustomers() throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			CustomerLocalHome customerLocalHome = (CustomerLocalHome)context.lookup(CustomerLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			Collection collection = customerLocalHome.findAll();
			
			//get value object from local object and add it to a collection
			//hole ValueObjekt vom LocalObjekt und fge es der collection hinzu
			Collection customerList = new ArrayList();
			for (Iterator iter = collection.iterator(); iter.hasNext();) {
				CustomerLocal element = (CustomerLocal) iter.next();
				customerList.add(element.getCustomerValue());
			}
			
			//return the collection of customers
			//zurck geben der Collection von Kunden
			return customerList;
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Get a customer by Name
	 * Auslesen eines Kunden anhand des Namen
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public CustomerValue getCustomerByName(String name) throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			CustomerLocalHome customerLocalHome = (CustomerLocalHome)context.lookup(CustomerLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			CustomerLocal customerLocal = customerLocalHome.findByName(name);
			
			//return the value object of customers
			//zurck geben des value objektes des Kunden
			return customerLocal.getCustomerValue();
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Get all Customers by book date
	 * Auslesen aller Kunden anhand des Bcherdatums
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public Collection getCustomerByBookPrice(Float price) throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			CustomerLocalHome customerLocalHome = (CustomerLocalHome)context.lookup(CustomerLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			Collection collection = customerLocalHome.findByBookPrice(price);
			
			//get value object from local object and add it to a collection
			//hole ValueObjekt vom LocalObjekt und fge es der collection hinzu
			Collection customerList = new ArrayList();
			for (Iterator iter = collection.iterator(); iter.hasNext();) {
				CustomerLocal element = (CustomerLocal) iter.next();
				customerList.add(element.getCustomerValue());
			}
			
			//return the collection of customers
			//zurck geben der Collection von Kunden
			return customerList;
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());	
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Get all books
	 * Auslesen aller Bcher
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public Collection getAllBooks() throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			BookLocalHome bookLocalHome = (BookLocalHome)context.lookup(BookLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			Collection collection = bookLocalHome.findAll();
			
			//get value object from local object and add it to a collection
			//hole ValueObjekt vom LocalObjekt und fge es der collection hinzu
			Collection bookList = new ArrayList();
			for (Iterator iter = collection.iterator(); iter.hasNext();) {
				BookLocal element = (BookLocal) iter.next();
				bookList.add(element.getBookValue());
			}
			
			//return the collection of books
			//zurck geben der Collection von Bchern
			return bookList;
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());	
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Get books by price range
	 * Auslesen von Bchern anhand einer Preisspanne
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public Collection getBooksByPriceRange(Float from, Float to) throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			BookLocalHome bookLocalHome = (BookLocalHome)context.lookup(BookLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			Collection collection = bookLocalHome.findByPriceRange(from, to);
			
			//get value object from local object and add it to a collection
			//hole ValueObjekt vom LocalObjekt und fge es der collection hinzu
			Collection bookList = new ArrayList();
			for (Iterator iter = collection.iterator(); iter.hasNext();) {
				BookLocal element = (BookLocal) iter.next();
				bookList.add(element.getBookValue());
			}
			
			//return the collection of books
			//zurck geben der Collection von Bchern
			return bookList;
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());	
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Get books by customer name
	 * Auslesen von Bchern anhand des Namen des Kunden
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public Collection getBooksByCustomerName(String name) throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			BookLocalHome bookLocalHome = (BookLocalHome)context.lookup(BookLocalHome.JNDI_NAME);
			
			//Call the finder methods
			//Aufrufen der Finder Methode
			Collection collection = bookLocalHome.findByCustomerName(name);
			
			//get value object from local object and add it to a collection
			//hole ValueObjekt vom LocalObjekt und fge es der collection hinzu
			Collection bookList = new ArrayList();
			for (Iterator iter = collection.iterator(); iter.hasNext();) {
				BookLocal element = (BookLocal) iter.next();
				bookList.add(element.getBookValue());
			}
			
			//return the collection of books
			//zurck geben der Collection von Bchern
			return bookList;
			
		} catch (FinderException e) {
			throw new EJBException(e.getMessage());	
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}
	
	/**
	 * Init some test datas
	 * Initalisieren von einigen Test-Daten
	 * 
	 * @ejb.interface-method view-type = "both"
	 */
	public void initSomeTestData() throws EJBException {
		
		try {
			InitialContext context = new InitialContext();
			//get the local home interface with JNDI from the application server 
			//hole das Local Home Interface ber JNDI vom Applikationserver
			BookLocalHome bookLocalHome = (BookLocalHome)context.lookup(BookLocalHome.JNDI_NAME);
			CustomerLocalHome customerLocalHome = (CustomerLocalHome)context.lookup(CustomerLocalHome.JNDI_NAME);
			
			//delete all existing data
			//lsche alle vorhandenen Daten
			try {
				for (Iterator iter = bookLocalHome.findAll().iterator(); iter.hasNext();) {
					BookLocal element = (BookLocal) iter.next();
					element.remove();
				}
				for (Iterator iter = customerLocalHome.findAll().iterator(); iter.hasNext();) {
					CustomerLocal element = (CustomerLocal) iter.next();
					element.remove();
				}
			} catch (EJBException e1) {
				e1.printStackTrace();
			} catch (FinderException e1) {
				e1.printStackTrace();
			} catch (RemoveException e1) {
				e1.printStackTrace();
			}
			
			//create some customers
			//erstelle einige kunden
			CustomerLocal customerLocal1 = customerLocalHome.create();
			customerLocal1.setName("Karl");
			customerLocal1.setAge(new Integer(34));

			CustomerLocal customerLocal2 = customerLocalHome.create();
			customerLocal2.setName("Betti");
			customerLocal2.setAge(new Integer(25));
			
			CustomerLocal customerLocal3 = customerLocalHome.create();
			customerLocal3.setName("Peter");
			customerLocal3.setAge(new Integer(65));
			
			//create some books
			//erstelle einige bcher
			BookLocal bookLocal1 = bookLocalHome.create();
			bookLocal1.setTitle("Lost in Space");
			bookLocal1.setPrice(new Float(10.99));
			
			BookLocal bookLocal2 = bookLocalHome.create();
			bookLocal2.setTitle("1984");
			bookLocal2.setPrice(new Float(20.99));
			
			BookLocal bookLocal3 = bookLocalHome.create();
			bookLocal3.setTitle("Hero");
			bookLocal3.setPrice(new Float(8.99));
			
			//set the relations between customer and book
			//setze die Beziehung zwischen Kunde und Book
			bookLocal1.setCustomer(customerLocal2);
			bookLocal2.setCustomer(customerLocal3);
			bookLocal3.setCustomer(customerLocal2);
	
		} catch (CreateException e) {
			throw new EJBException(e.getMessage());	
		} catch (NamingException e) {
			throw new EJBException(e.getMessage());
		}
	}

	/** The SessionContext */
	private SessionContext context;

	/**
	 * An <code>ejbCreate</code> method as required by the EJB specification. <br>
	 * 
	 * The container calls the instances <code>ejbCreate</code> method whose 
	 * signature matches the signature of the <code>create</code> method invoked 
	 * by the client. The input parameters sent from the client are passed to
	 * the <code>ejbCreate</code> method. Each session bean class must have at
	 * least one <code>ejbCreate</code> method. The number and signatures
	 * of a session beans <code>create</code> methods are specific to each 
	 * session bean class.
	 * 
	 * @throws CreateException Thrown if the instance could not perform 
	 * the function requested by the container because of an system-level error.
	 * 
	 * @ejb.create-method
	 */
	public void ejbCreate() throws CreateException {
	}

	/**
	 * The <code>ejbActivate()</code> method as required by the EJB specification.<br>
	 *
	 * The activate method is called when the instance is activated from its 
	 * passive" state. The instance should acquire any resource that it has 
	 * released earlier in the <code>ejbPassivate()</code> method. <br>
	 * 
	 * This method is called with no transaction context. 
	 * 
	 * @throws EJBException Thrown if the instance could not perform 
	 * the function requested by the container because of an system-level error.
	 */
	public void ejbActivate() throws EJBException {
	}

	/**
	 * The <code>ejbPassivate()</code> method as required by the EJB specification.<br>
	 *
	 * The activate method is called when the instance is activated from 
	 * its "passive" state. The instance should acquire any resource that 
	 * it has released earlier in the <code>ejbActivate()</code> method.  <br>
	 * 
	 * This method is called with no transaction context. 
	 * 
	 * @throws EJBException Thrown if the instance could not perform 
	 * the function requested by the container because of an system-level error.
	 */
	public void ejbPassivate() throws EJBException {
	}

	/**
	 * The <code>ejbRemove()</code> method as required by the EJB specification.<br>
	 *
	 * A container invokes this method before it ends the life of the 
	 * session object. This happens as a result of a client's invoking 
	 * a remove operation, or when a container decides to terminate the 
	 * session object after a timeout.   <br>
	 * 
	 * This method is called with no transaction context. 
	 * 
	 * @throws EJBException Thrown if the instance could not perform 
	 * the function requested by the container because of an system-level error.
	 */
	public void ejbRemove() throws EJBException {
	}

	/**
	 * Set the associated session context. The container calls this method 
	 * after the instance creation.  <br>
	 * 
	 * The enterprise bean instance should store the reference to the context 
	 * object in an instance variable. <br>
	 * 
	 * This method is called with no transaction context. 
	 * 
	 * @throws EJBException Thrown if the instance could not perform 
	 * the function requested by the container because of an system-level error.
	 */
	public void setSessionContext(SessionContext newContext)
			throws EJBException {
		context = newContext;
	}

}
